==> express-audio-2.2.1-sources.jar: im/zego/zegoexpress/constants/ZegoVoiceChangerPreset.java <==
package im.zego.zegoexpress.constants;

/** Voice changer preset value. */
public enum ZegoVoiceChangerPreset {
    /** No Voice changer */
    NONE(0),
    /** Male to child voice (loli voice effect) */
    MEN_TO_CHILD(1),
    /** Male to female voice (kindergarten voice effect) */
    MEN_TO_WOMEN(2),
    /** Female to child voice */
    WOMEN_TO_CHILD(3),
    /** Female to male voice */
    WOMEN_TO_MEN(4),
    /** Foreigner voice effect */
    FOREIGNER(5),
    /** Autobot Optimus Prime voice effect */
    OPTIMUS_PRIME(6),
    /** Android robot voice effect */
    ANDROID(7),
    /** Ethereal voice effect */
    ETHEREAL(8),
    /** Magnetic(Male) voice effect */
    MALE_MAGNETIC(9),
    /** Fresh(Female) voice effect */
    FEMALE_FRESH(10);

    private int value;

    private ZegoVoiceChangerPreset(int value) {
        this.value = value;
    }

    public int value() {
        return this.value;
    }

    public static ZegoVoiceChangerPreset getZegoVoiceChangerPreset(int value) {
        try {

            if (NONE.value == value) {
                return NONE;
            }

            if (MEN_TO_CHILD.value == value) {
                return MEN_TO_CHILD;
            }

            if (MEN_TO_WOMEN.value == value) {
                return MEN_TO_WOMEN;
            }

            if (WOMEN_TO_CHILD.value == value) {
                return WOMEN_TO_CHILD;
            }

            if (WOMEN_TO_MEN.value == value) {
                return WOMEN_TO_MEN;
            }

            if (FOREIGNER.value == value) {
                return FOREIGNER;
            }

            if (OPTIMUS_PRIME.value == value) {
                return OPTIMUS_PRIME;
            }

            if (ANDROID.value == value) {
                return ANDROID;
            }

            if (ETHEREAL.value == value) {
                return ETHEREAL;
            }

            if (MALE_MAGNETIC.value == value) {
                return MALE_MAGNETIC;
            }

            if (FEMALE_FRESH.value == value) {
                return FEMALE_FRESH;
            }

        } catch (Exception e) {
            throw new RuntimeException("The enumeration cannot be found");
        }
        return null;
    }
}

==> express-audio-2.3.0-sources.jar: im/zego/zegoexpress/constants/ZegoVoiceChangerPreset.java <==
package im.zego.zegoexpress.constants;

import im.zego.zegoexpress.constants.*;
import im.zego.zegoexpress.callback.*;
import im.zego.zegoexpress.entity.*;
import java.nio.*;
import java.util.*;
import org.json.*;
import im.zego.zegoexpress.*;
import im.zego.zegoexpress.internal.*;
import android.app.Application;
import android.graphics.*;

/**
 * Voice changer preset value
 *
 */
public enum ZegoVoiceChangerPreset {

    /**
     * No Voice changer
     */
    NONE(0),

    /**
     * Male to child voice (loli voice effect)
     */
    MEN_TO_CHILD(1),

    /**
     * male to female voices (kindergarten voice effect)
     */
    MEN_TO_WOMEN(2),

    /**
     * Female to child voice
     */
    WOMEN_TO_CHILD(3),

    /**
     * Female Voice to Male Voice
     */
    WOMEN_TO_MEN(4),

    /**
     * Foreigner voice effect
     */
    FOREIGNER(5),

    /**
     * Autobot Optimus Prime voice effect
     */
    OPTIMUS_PRIME(6),

    /**
     * Android robot voice effect
     */
    ANDROID(7),

    /**
     * Ethereal voice effect
     */
    ETHEREAL(8),

    /**
     * Magnetic(Male) voice effect
     */
    MALE_MAGNETIC(9),

    /**
     * Fresh(Female) voice effect
     */
    FEMALE_FRESH(10);

    private int value;

    private ZegoVoiceChangerPreset(int value) {
        this.value = value;
    }

    public int value() {
        return this.value;
    }

    public static ZegoVoiceChangerPreset getZegoVoiceChangerPreset(int value) {
        try {

            if (NONE.value == value) {
                return NONE;
            }

            if (MEN_TO_CHILD.value == value) {
                return MEN_TO_CHILD;
            }

            if (MEN_TO_WOMEN.value == value) {
                return MEN_TO_WOMEN;
            }

            if (WOMEN_TO_CHILD.value == value) {
                return WOMEN_TO_CHILD;
            }

            if (WOMEN_TO_MEN.value == value) {
                return WOMEN_TO_MEN;
            }

            if (FOREIGNER.value == value) {
                return FOREIGNER;
            }

            if (OPTIMUS_PRIME.value == value) {
                return OPTIMUS_PRIME;
            }

            if (ANDROID.value == value) {
                return ANDROID;
            }

            if (ETHEREAL.value == value) {
                return ETHEREAL;
            }

            if (MALE_MAGNETIC.value == value) {
                return MALE_MAGNETIC;
            }

            if (FEMALE_FRESH.value == value) {
                return FEMALE_FRESH;
            }

        } catch (Exception e) {
            throw new RuntimeException("The enumeration cannot be found");
        }
        return null;
    }

}
